import qrcode from "qrcode-generator";
export class QRCodeWebComponent {
    constructor() {
        this.contents = 'Hello World';
        this.errorCorrectionLevel = 'H';
        this.margin = 4;
        this.scale = 4;
        this.colorDark = '#000000ff';
        this.colorLight = '#ffffffff';
        this.outputMode = 'DataURI';
    }
    componentWillLoad() {
        this.computeAndSetData(this.contents, this.outputMode);
    }
    computeAndSetData(text, outputMode) {
        const qr = qrcode(0, this.errorCorrectionLevel);
        qr.addData(text);
        qr.make();
        if (outputMode === 'DataURI') {
            this.data = qr.createImgTag();
        }
        else if (outputMode === 'SVG') {
            this.data = qr.createSvgTag();
        }
        else if (outputMode === 'Table') {
            this.data = qr.createTableTag();
        }
        else {
            this.data = null;
        }
    }
    changeOutputModeHandler(newValue) {
        this.computeAndSetData(this.contents, newValue);
    }
    changeContentsHandler(newValue) {
        console.log('contents changed', newValue);
        this.computeAndSetData(newValue, this.outputMode);
    }
    changeErrorCorrectionLevelHandler() {
        this.computeAndSetData(this.contents, this.outputMode);
    }
    render() {
        return h("div", { innerHTML: this.data });
    }
    static get is() { return "qr-code"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return {
        "colorDark": {
            "type": String,
            "attr": "color-dark"
        },
        "colorLight": {
            "type": String,
            "attr": "color-light"
        },
        "contents": {
            "type": String,
            "attr": "contents",
            "watchCallbacks": ["changeContentsHandler"]
        },
        "data": {
            "state": true
        },
        "errorCorrectionLevel": {
            "type": String,
            "attr": "error-correction-level",
            "watchCallbacks": ["changeErrorCorrectionLevelHandler"]
        },
        "margin": {
            "type": Number,
            "attr": "margin"
        },
        "outputMode": {
            "type": String,
            "attr": "output-mode",
            "watchCallbacks": ["changeOutputModeHandler"]
        },
        "scale": {
            "type": Number,
            "attr": "scale"
        }
    }; }
    static get style() { return "/**style-placeholder:qr-code:**/"; }
}
